@@ -20,6 +20,7 @@
 #' @param oda the original data frame of associations when argument ant is obtained with perm.ds.grp or perm.ds.focal ANT functions.
 #' @param progress a boolean indicating the visualization of the permutation process.
 #' @param ... Extra arguments for \code{\link[lme4]{lmer}} or \code{\link[lme4]{glmer}} function only.
+#' @param ncores an integer indicating the number of jobs to create for parallelization.
 #' @details GLMM with permutation data.
 #' @return Returns a list of 3 elements :
 #' \itemize{
@@ -48,9 +49,15 @@
 #' t=perm.net.nl(t,labels='age',rf="period",nperm=10,progress=FALSE) 
 #' # Permuted GLMM-------------------------------------------------------------
 #' r.glmm=stat.glmm(ant = t,formula = strength ~ age + (1|id),family = gaussian(), progress=TRUE)
+#' # Rstudio parallelization.----------------------------
+#'  \dontrun{r.glmm=stat.glmm(t,formula = strength ~ age + (1|id),family = gaussian(), ncores = 10)}
 #' @author Sebastian Sosa, Ivan Puga-Gonzalez.
 
-stat.glmm <- function(ant, formula, family, oda = NULL, progress = TRUE, ...) {
+stat.glmm <- function(ant, formula, family, oda = NULL, progress = TRUE, ncores = 1,...) {
+  if(ncores > 1){
+    result = stat.glmm.parallel(ant = ant,formula = formula,family = family, progress= progress, ncores = ncores, ...)
+    return(result)
+  }
   if (is.null(attributes(ant)$ANT)) {
     stop("Argument ant must be an object returned by perm.ds.grp, per.ds.focal or per.ds.nl functions")
   }
